################
accretion_common
################

.. image:: https://img.shields.io/pypi/v/accretion_common.svg
   :target: https://pypi.python.org/pypi/accretion_common
   :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/accretion_common.svg
   :target: https://pypi.python.org/pypi/accretion_common
   :alt: Supported Python Versions

.. image:: https://img.shields.io/badge/code_style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Code style: black

.. image:: https://readthedocs.org/projects/accretion_common/badge/
   :target: https://accretion_common.readthedocs.io/en/stable/
   :alt: Documentation Status

.. image:: https://travis-ci.org/accretion/accretion_common.svg?branch=master
   :target: https://travis-ci.org/accretion/accretion_common
   :alt: Travis CI Test Status

.. image:: https://ci.appveyor.com/api/projects/status/REPLACEME/branch/master?svg=true
   :target: https://ci.appveyor.com/project/REPLACEME
   :alt: AppVeyor Test Status

.. warning::

    This package is intended only for internal use within Accretion.
    This documentation is provided for information purposes only.
    No guarantee is provided on the modules and APIs described in here remaining consistent.
    Directly reference at your own risk.

Common resources for Accretion components.
